/* $Header: /fridge/cvs/xscorch/sutil/sslink.h,v 1.4 2004/02/26 06:34:57 justins Exp $ */
/*

   xscorch - sslink.h         Copyright(c) 2000 Jacob Luna Lundberg
   jacob(at)chaos2.org        http://chaos2.org/~jacob

   A very slim slink list library for xscorch.


   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY. 

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef __sslink_h_included
#define __sslink_h_included



/* The basic slink list prototype. */
typedef struct _slinklist {
   struct _slinklist  *next;    /* Place the next pointer first, folks */
   void               *data;    /* I recommend placing the data second */
} slinklist;



/* Predefined operations on slink lists. */
slinklist *slink_last(slinklist *head);
slinklist *slink_insert(slinklist *head, slinklist *item);
slinklist *slink_append(slinklist *head, slinklist *item);



#endif /* __sslink_h_included */
